Gromacs building blocks — GromacsWrapper 0.6.1 documentation

# Gromacs building blocks

Building blocks are small classes or functions that can be freely combined in setup or analysis scripts or used interactively. These modules act as “library” for common tasks.

- `gromacs.cbook` – Gromacs Cook Book
  - Miscellaneous canned Gromacs commands
  - Manipulating trajectories and structures
  - Processing output
  - Working with topologies and mdp files
  - Working with index files
  - File editing functions
- `gromacs.setup` – Setting up a Gromacs MD run
  - User functions
  - Example
  - User functions
  - Helper functions
- `gromacs.scaling` – Partial tempering
- `gromacs.qsub` – utilities for batch submission systems
  - Queuing system templates
  - Classes and functions
- Managing jobs remotely
  - Configuration file
  - Queuing system Manager
  - Helper classes and functions
- `gromacs.run` – Running simulations
  - Example implementations
  - Helper functions